==> codedeploy-0.26.0-sources.jar: software/amazon/awscdk/services/codedeploy/ServerDeploymentGroupImportProps.java <==
package software.amazon.awscdk.services.codedeploy;

/**
 * Properties of a reference to a CodeDeploy EC2/on-premise Deployment Group.
 * @see IServerDeploymentGroup#export
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T13:02:28.207Z")
public interface ServerDeploymentGroupImportProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * The reference to the CodeDeploy EC2/on-premise Application
     * that this Deployment Group belongs to.
     */
    software.amazon.awscdk.services.codedeploy.IServerApplication getApplication();
    /**
     * The reference to the CodeDeploy EC2/on-premise Application
     * that this Deployment Group belongs to.
     */
    void setApplication(final software.amazon.awscdk.services.codedeploy.IServerApplication value);
    /**
     * The physical, human-readable name of the CodeDeploy EC2/on-premise Deployment Group
     * that we are referencing.
     */
    java.lang.String getDeploymentGroupName();
    /**
     * The physical, human-readable name of the CodeDeploy EC2/on-premise Deployment Group
     * that we are referencing.
     */
    void setDeploymentGroupName(final java.lang.String value);
    /**
     * The Deployment Configuration this Deployment Group uses.
     * @default ServerDeploymentConfig#OneAtATime
     */
    software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig getDeploymentConfig();
    /**
     * The Deployment Configuration this Deployment Group uses.
     * @default ServerDeploymentConfig#OneAtATime
     */
    void setDeploymentConfig(final software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig value);

    /**
     * @return a {@link Builder} of {@link ServerDeploymentGroupImportProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ServerDeploymentGroupImportProps}
     */
    final class Builder {
        private software.amazon.awscdk.services.codedeploy.IServerApplication _application;
        private java.lang.String _deploymentGroupName;
        @javax.annotation.Nullable
        private software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig _deploymentConfig;

        /**
         * Sets the value of Application
         * @param value The reference to the CodeDeploy EC2/on-premise Application
that this Deployment Group belongs to.
         * @return {@code this}
         */
        public Builder withApplication(final software.amazon.awscdk.services.codedeploy.IServerApplication value) {
            this._application = java.util.Objects.requireNonNull(value, "application is required");
            return this;
        }
        /**
         * Sets the value of DeploymentGroupName
         * @param value The physical, human-readable name of the CodeDeploy EC2/on-premise Deployment Group
that we are referencing.
         * @return {@code this}
         */
        public Builder withDeploymentGroupName(final java.lang.String value) {
            this._deploymentGroupName = java.util.Objects.requireNonNull(value, "deploymentGroupName is required");
            return this;
        }
        /**
         * Sets the value of DeploymentConfig
         * @param value The Deployment Configuration this Deployment Group uses.
         * @return {@code this}
         */
        public Builder withDeploymentConfig(@javax.annotation.Nullable final software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig value) {
            this._deploymentConfig = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ServerDeploymentGroupImportProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public ServerDeploymentGroupImportProps build() {
            return new ServerDeploymentGroupImportProps() {
                private software.amazon.awscdk.services.codedeploy.IServerApplication $application = java.util.Objects.requireNonNull(_application, "application is required");
                private java.lang.String $deploymentGroupName = java.util.Objects.requireNonNull(_deploymentGroupName, "deploymentGroupName is required");
                @javax.annotation.Nullable
                private software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig $deploymentConfig = _deploymentConfig;

                @Override
                public software.amazon.awscdk.services.codedeploy.IServerApplication getApplication() {
                    return this.$application;
                }

                @Override
                public void setApplication(final software.amazon.awscdk.services.codedeploy.IServerApplication value) {
                    this.$application = java.util.Objects.requireNonNull(value, "application is required");
                }

                @Override
                public java.lang.String getDeploymentGroupName() {
                    return this.$deploymentGroupName;
                }

                @Override
                public void setDeploymentGroupName(final java.lang.String value) {
                    this.$deploymentGroupName = java.util.Objects.requireNonNull(value, "deploymentGroupName is required");
                }

                @Override
                public software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig getDeploymentConfig() {
                    return this.$deploymentConfig;
                }

                @Override
                public void setDeploymentConfig(@javax.annotation.Nullable final software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig value) {
                    this.$deploymentConfig = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.codedeploy.ServerDeploymentGroupImportProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The reference to the CodeDeploy EC2/on-premise Application
         * that this Deployment Group belongs to.
         */
        @Override
        public software.amazon.awscdk.services.codedeploy.IServerApplication getApplication() {
            return this.jsiiGet("application", software.amazon.awscdk.services.codedeploy.IServerApplication.class);
        }

        /**
         * The reference to the CodeDeploy EC2/on-premise Application
         * that this Deployment Group belongs to.
         */
        @Override
        public void setApplication(final software.amazon.awscdk.services.codedeploy.IServerApplication value) {
            this.jsiiSet("application", java.util.Objects.requireNonNull(value, "application is required"));
        }

        /**
         * The physical, human-readable name of the CodeDeploy EC2/on-premise Deployment Group
         * that we are referencing.
         */
        @Override
        public java.lang.String getDeploymentGroupName() {
            return this.jsiiGet("deploymentGroupName", java.lang.String.class);
        }

        /**
         * The physical, human-readable name of the CodeDeploy EC2/on-premise Deployment Group
         * that we are referencing.
         */
        @Override
        public void setDeploymentGroupName(final java.lang.String value) {
            this.jsiiSet("deploymentGroupName", java.util.Objects.requireNonNull(value, "deploymentGroupName is required"));
        }

        /**
         * The Deployment Configuration this Deployment Group uses.
         * @default ServerDeploymentConfig#OneAtATime
         */
        @Override
        @javax.annotation.Nullable
        public software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig getDeploymentConfig() {
            return this.jsiiGet("deploymentConfig", software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class);
        }

        /**
         * The Deployment Configuration this Deployment Group uses.
         * @default ServerDeploymentConfig#OneAtATime
         */
        @Override
        public void setDeploymentConfig(@javax.annotation.Nullable final software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig value) {
            this.jsiiSet("deploymentConfig", value);
        }
    }
}

==> codedeploy-0.27.0-sources.jar: software/amazon/awscdk/services/codedeploy/ServerDeploymentGroupImportProps.java <==
package software.amazon.awscdk.services.codedeploy;

/**
 * Properties of a reference to a CodeDeploy EC2/on-premise Deployment Group.
 * @see IServerDeploymentGroup#export
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-03-28T21:40:39.007Z")
public interface ServerDeploymentGroupImportProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * The reference to the CodeDeploy EC2/on-premise Application
     * that this Deployment Group belongs to.
     */
    software.amazon.awscdk.services.codedeploy.IServerApplication getApplication();
    /**
     * The physical, human-readable name of the CodeDeploy EC2/on-premise Deployment Group
     * that we are referencing.
     */
    java.lang.String getDeploymentGroupName();
    /**
     * The Deployment Configuration this Deployment Group uses.
     * @default ServerDeploymentConfig#OneAtATime
     */
    software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig getDeploymentConfig();

    /**
     * @return a {@link Builder} of {@link ServerDeploymentGroupImportProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ServerDeploymentGroupImportProps}
     */
    final class Builder {
        private software.amazon.awscdk.services.codedeploy.IServerApplication _application;
        private java.lang.String _deploymentGroupName;
        @javax.annotation.Nullable
        private software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig _deploymentConfig;

        /**
         * Sets the value of Application
         * @param value The reference to the CodeDeploy EC2/on-premise Application
that this Deployment Group belongs to.
         * @return {@code this}
         */
        public Builder withApplication(final software.amazon.awscdk.services.codedeploy.IServerApplication value) {
            this._application = java.util.Objects.requireNonNull(value, "application is required");
            return this;
        }
        /**
         * Sets the value of DeploymentGroupName
         * @param value The physical, human-readable name of the CodeDeploy EC2/on-premise Deployment Group
that we are referencing.
         * @return {@code this}
         */
        public Builder withDeploymentGroupName(final java.lang.String value) {
            this._deploymentGroupName = java.util.Objects.requireNonNull(value, "deploymentGroupName is required");
            return this;
        }
        /**
         * Sets the value of DeploymentConfig
         * @param value The Deployment Configuration this Deployment Group uses.
         * @return {@code this}
         */
        public Builder withDeploymentConfig(@javax.annotation.Nullable final software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig value) {
            this._deploymentConfig = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ServerDeploymentGroupImportProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public ServerDeploymentGroupImportProps build() {
            return new ServerDeploymentGroupImportProps() {
                private final software.amazon.awscdk.services.codedeploy.IServerApplication $application = java.util.Objects.requireNonNull(_application, "application is required");
                private final java.lang.String $deploymentGroupName = java.util.Objects.requireNonNull(_deploymentGroupName, "deploymentGroupName is required");
                @javax.annotation.Nullable
                private final software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig $deploymentConfig = _deploymentConfig;

                @Override
                public software.amazon.awscdk.services.codedeploy.IServerApplication getApplication() {
                    return this.$application;
                }

                @Override
                public java.lang.String getDeploymentGroupName() {
                    return this.$deploymentGroupName;
                }

                @Override
                public software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig getDeploymentConfig() {
                    return this.$deploymentConfig;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("application", om.valueToTree(this.getApplication()));
                    obj.set("deploymentGroupName", om.valueToTree(this.getDeploymentGroupName()));
                    obj.set("deploymentConfig", om.valueToTree(this.getDeploymentConfig()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.codedeploy.ServerDeploymentGroupImportProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The reference to the CodeDeploy EC2/on-premise Application
         * that this Deployment Group belongs to.
         */
        @Override
        public software.amazon.awscdk.services.codedeploy.IServerApplication getApplication() {
            return this.jsiiGet("application", software.amazon.awscdk.services.codedeploy.IServerApplication.class);
        }

        /**
         * The physical, human-readable name of the CodeDeploy EC2/on-premise Deployment Group
         * that we are referencing.
         */
        @Override
        public java.lang.String getDeploymentGroupName() {
            return this.jsiiGet("deploymentGroupName", java.lang.String.class);
        }

        /**
         * The Deployment Configuration this Deployment Group uses.
         * @default ServerDeploymentConfig#OneAtATime
         */
        @Override
        @javax.annotation.Nullable
        public software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig getDeploymentConfig() {
            return this.jsiiGet("deploymentConfig", software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class);
        }
    }
}
